ampliconduo(A, B = NULL, sample.names = NULL, correction = "fdr", ...)"holm", "hochberg", "hommel",
"bonferroni", "BH", "BY","fdr" and "none". Default is fisher.test function.sample.names or numbered.Each ampliconduo data frame has 9 columns
Bif specified)ORORsample.nameif specified, same for all rows in a given data frameA is specified, it is assumed that the list elements 1 &
2, 3 & 4 etc. of A are amplicon data of the same sample. In case A and B
are specified, the ith frequency set of A and B
are combined. For each amplicon data pair, frequencies at the corresponding
positions in the lists are assumed to belong to the same amplicon. It is required, that two frequency sets that belong to the same sample, an ampliconduo, have the same length. The ampliconduo function iterates over all amplicon pairs and performs the following tasks:
fisher.test
is performed. The p-value, odds ratio and confidence interval are returned. Via the ..., arguments
conf.level, or and alternative can be passed to the fisher.test function call. Default values are conf.level = 0.95, or = 1 and alternative = "two.sided".p.adjust function. By default the method by Benjamini & Hochberg (1995) is used.
Setting the correction argument to any of the following characters "holm", "hochberg", "hommel", "bonferroni", "BH", "BY", "fdr", "none", the adjustment method for the p-values can be changed. See function p.adjust.fisher.test, used to calculate the p-value, odds ratio and confidence interval; p.adjust, called to correct the p-values;
methods to visualize or further manipulate the ampliconduo data frames:
## loads read numbers from example amplicon data sets
data(ampliconfreqs)
data(site.f)
## generate ampliconduo data frames
ampliconduos.a <- ampliconduo(A = ampliconfreqs[,1:4], sample.names = site.f[1:2])
ampliconduos.b <- ampliconduo(A = ampliconfreqs[c(1,3)],
B = ampliconfreqs[c(2,4)], sample.names = site.f[1:2],
conf.level = 0.9)
## frequency plot
plotAmpliconduo.set(ampliconduos.a)Run the code above in your browser using DataLab