ampliconfreqs: SSU Amplicon Frequencies Of Different Sampling Sites (Short Version)
Description
A data frame with 16 amplicon data sets taken from 8 different sampling sites. A reduced version (frequencies of 2500 amplicons) of the ampliconfreqs.long data provided with this package.
Samples from each sampling site were sequenced twice, corresponding to sets A and B (e.g. column FU25.A and FU25.B).
Names of the sampling sites are specified in the data site.f.
Usage
data(ampliconfreqs)
Arguments
References
Boenigk J, Heider D, Jost S, Lange A, Budeus B, Schilling E,
Strittmatter A, Hoffmann D: A high-throughput amplicon sequencing and
analysis protocol for comparative analyses of microbial communities
(submitted)