discordance.delta(x, names = NULL, theta = 0.05, corrected = TRUE,
printToTex = FALSE, directory = NULL, file.name = NULL)ampliconduo function.
x.
TRUE writes a file with the resulting table in Tex format. Default is FALSE.
printToTex is TRUE, the output file will be saved in the specified directory.
printToTex is TRUE, the output file will have the name file.name.
$$ \Delta_{S\theta} = \frac{\sum_{i=1}^{n_S}(r_{iAS}+r_{iBS})\delta(q_{iS}<\theta)}{\sum_{i=1}^{n_s}(r_{ias}+r_{ibs})}\\ $$<="" p="">
$$ \Delta'_{S\theta} = \frac{\sum_{i=1}^{n_S}\delta(q_{iS}<\theta)}{n_s},\\ $$<="" p="">
$$ \mathrm{with\;} \delta(q_{iS}<\theta) 0="" 1="" =="" \left\{="" \begin{array}{cc}="" &="" \mathrm{\;for\;}="" q_{is}="" <="" \theta\\="" \ge="" \theta="" \end{array}="" \right.="" $$<="" p="">
discordanceDelta.pngoptions: width="400"
for number $n_S$ of amplicons detected in sample/ampliconduo S. $\Delta_{S\theta}$ and $\Delta'_{S\theta}$ are located between 0 (no discordance, i.e. no statistically significant deviations between experimental branches) and 1 (complete discordance).
x is the return value of a ampliconduo call.
ampliconduo, generates the expected data format for x
xtable, used to convert the returned data frame into a Latex table.
## load example ampliconduo data frame
data(amplicons)
## calculate the discordance between amplicon data sets of an ampliconduo data frame
dd.a <- discordance.delta(amplicons)
dd.b <- discordance.delta(amplicons, theta = 0.1)
dd.c <- discordance.delta(amplicons, printToTex = TRUE)
Run the code above in your browser using DataLab